@@ -38,19 +38,19 @@ void JSPolicies::load()
 //  enableJavaScriptDebugCB->setChecked( m_pConfig->readEntry("EnableJavaScriptDebug", QVariant(false)).toBool());
 //  enableDebugOutputCB->setChecked( m_pConfig->readEntry("EnableJSDebugOutput", QVariant(false)).toBool() );
     key = prefix + "WindowOpenPolicy";
-    window_open = cg.readEntry(key, (is_global ? KParts::HtmlSettingsInterface::JSWindowOpenSmart : INHERIT_POLICY));
+    window_open = cg.readEntry(key, (is_global ? HtmlSettingsInterface::JSWindowOpenSmart : INHERIT_POLICY));
 
     key = prefix + "WindowResizePolicy";
-    window_resize = cg.readEntry(key, (is_global ? KParts::HtmlSettingsInterface::JSWindowResizeAllow : INHERIT_POLICY));
+    window_resize = cg.readEntry(key, (is_global ? HtmlSettingsInterface::JSWindowResizeAllow : INHERIT_POLICY));
 
     key = prefix + "WindowMovePolicy";
-    window_move = cg.readEntry(key, (is_global ? KParts::HtmlSettingsInterface::JSWindowMoveAllow : INHERIT_POLICY));
+    window_move = cg.readEntry(key, (is_global ? HtmlSettingsInterface::JSWindowMoveAllow : INHERIT_POLICY));
 
     key = prefix + "WindowFocusPolicy";
-    window_focus = cg.readEntry(key, (is_global ? KParts::HtmlSettingsInterface::JSWindowFocusAllow : INHERIT_POLICY));
+    window_focus = cg.readEntry(key, (is_global ? HtmlSettingsInterface::JSWindowFocusAllow : INHERIT_POLICY));
 
     key = prefix + "WindowStatusPolicy";
-    window_status = cg.readEntry(key, (is_global ? KParts::HtmlSettingsInterface::JSWindowStatusAllow : INHERIT_POLICY));
+    window_status = cg.readEntry(key, (is_global ? HtmlSettingsInterface::JSWindowStatusAllow : INHERIT_POLICY));
 }
 
 void JSPolicies::defaults()
@@ -60,11 +60,11 @@ void JSPolicies::defaults()
 //  enableJavaScriptDebugCB->setChecked( false );
 //  js_popup->setButton(0);
 // enableDebugOutputCB->setChecked( false );
-    window_open = (is_global ? KParts::HtmlSettingsInterface::JSWindowOpenSmart : INHERIT_POLICY);
-    window_resize = (is_global ? KParts::HtmlSettingsInterface::JSWindowResizeAllow : INHERIT_POLICY);
-    window_move = (is_global ? KParts::HtmlSettingsInterface::JSWindowMoveAllow : INHERIT_POLICY);
-    window_focus = (is_global ? KParts::HtmlSettingsInterface::JSWindowFocusAllow : INHERIT_POLICY);
-    window_status = (is_global ? KParts::HtmlSettingsInterface::JSWindowStatusAllow : INHERIT_POLICY);
+    window_open = (is_global ? HtmlSettingsInterface::JSWindowOpenSmart : INHERIT_POLICY);
+    window_resize = (is_global ? HtmlSettingsInterface::JSWindowResizeAllow : INHERIT_POLICY);
+    window_move = (is_global ? HtmlSettingsInterface::JSWindowMoveAllow : INHERIT_POLICY);
+    window_focus = (is_global ? HtmlSettingsInterface::JSWindowFocusAllow : INHERIT_POLICY);
+    window_status = (is_global ? HtmlSettingsInterface::JSWindowStatusAllow : INHERIT_POLICY);
 }
 
 void JSPolicies::save()
@@ -146,19 +146,19 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
 
     policy_btn = new QRadioButton(i18n("Allow"), this);
     policy_btn->setToolTip(i18n("Accept all popup window requests."));
-    js_popup->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowOpenAllow);
+    js_popup->addButton(policy_btn, HtmlSettingsInterface::JSWindowOpenAllow);
     this_layout->addWidget(policy_btn, 0, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
     policy_btn = new QRadioButton(i18n("Ask"), this);
     policy_btn->setToolTip(i18n("Prompt every time a popup window is requested."));
-    js_popup->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowOpenAsk);
+    js_popup->addButton(policy_btn, HtmlSettingsInterface::JSWindowOpenAsk);
     this_layout->addWidget(policy_btn, 0, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
     policy_btn = new QRadioButton(i18n("Deny"), this);
     policy_btn->setToolTip(i18n("Reject all popup window requests."));
-    js_popup->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowOpenDeny);
+    js_popup->addButton(policy_btn, HtmlSettingsInterface::JSWindowOpenDeny);
     this_layout->addWidget(policy_btn, 0, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -166,7 +166,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
     policy_btn->setToolTip(i18n("Accept popup window requests only when "
                                   "links are activated through an explicit "
                                   "mouse click or keyboard operation."));
-    js_popup->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowOpenSmart);
+    js_popup->addButton(policy_btn, HtmlSettingsInterface::JSWindowOpenSmart);
     this_layout->addWidget(policy_btn, 0, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -200,7 +200,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
 
     policy_btn = new QRadioButton(i18n("Allow"), this);
     policy_btn->setToolTip(i18n("Allow scripts to change the window size."));
-    js_resize->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowResizeAllow);
+    js_resize->addButton(policy_btn, HtmlSettingsInterface::JSWindowResizeAllow);
     this_layout->addWidget(policy_btn, 1, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -208,7 +208,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
     policy_btn->setToolTip(i18n("Ignore attempts of scripts to change the window size. "
                                   "The web page will <i>think</i> it changed the "
                                   "size but the actual window is not affected."));
-    js_resize->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowResizeIgnore);
+    js_resize->addButton(policy_btn, HtmlSettingsInterface::JSWindowResizeIgnore);
     this_layout->addWidget(policy_btn, 1, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -237,7 +237,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
 
     policy_btn = new QRadioButton(i18n("Allow"), this);
     policy_btn->setToolTip(i18n("Allow scripts to change the window position."));
-    js_move->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowMoveAllow);
+    js_move->addButton(policy_btn, HtmlSettingsInterface::JSWindowMoveAllow);
     this_layout->addWidget(policy_btn, 2, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -245,7 +245,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
     policy_btn->setToolTip(i18n("Ignore attempts of scripts to change the window position. "
                                   "The web page will <i>think</i> it moved the "
                                   "window but the actual position is not affected."));
-    js_move->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowMoveIgnore);
+    js_move->addButton(policy_btn, HtmlSettingsInterface::JSWindowMoveIgnore);
     this_layout->addWidget(policy_btn, 2, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -274,7 +274,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
 
     policy_btn = new QRadioButton(i18n("Allow"), this);
     policy_btn->setToolTip(i18n("Allow scripts to focus the window."));
-    js_focus->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowFocusAllow);
+    js_focus->addButton(policy_btn, HtmlSettingsInterface::JSWindowFocusAllow);
     this_layout->addWidget(policy_btn, 3, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -283,7 +283,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
                                   "The web page will <i>think</i> it brought "
                                   "the focus to the window but the actual "
                                   "focus will remain unchanged."));
-    js_focus->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowFocusIgnore);
+    js_focus->addButton(policy_btn, HtmlSettingsInterface::JSWindowFocusIgnore);
     this_layout->addWidget(policy_btn, 3, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -314,7 +314,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
 
     policy_btn = new QRadioButton(i18n("Allow"), this);
     policy_btn->setToolTip(i18n("Allow scripts to change the text of the status bar."));
-    js_statusbar->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowStatusAllow);
+    js_statusbar->addButton(policy_btn, HtmlSettingsInterface::JSWindowStatusAllow);
     this_layout->addWidget(policy_btn, 4, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
@@ -323,7 +323,7 @@ JSPoliciesFrame::JSPoliciesFrame(JSPolicies *policies, const QString &title,
                                   "The web page will <i>think</i> it changed "
                                   "the text but the actual text will remain "
                                   "unchanged."));
-    js_statusbar->addButton(policy_btn, KParts::HtmlSettingsInterface::JSWindowStatusIgnore);
+    js_statusbar->addButton(policy_btn, HtmlSettingsInterface::JSWindowStatusIgnore);
     this_layout->addWidget(policy_btn, 4, colIdx++);
     this_layout->addItem(new QSpacerItem(10, 0), 0, colIdx++);
 
