@@ -12,6 +12,8 @@
 #include "konqfactory.h"
 #include "konqframe.h"
 #include "konqutils.h"
+#include "kf5compat.h" //For NavigationExtension
+#include "browserarguments.h"
 
 #include <kservice.h>
 #include <QMimeType>
@@ -29,22 +31,30 @@ class UrlLoader;
 class KonqFrame;
 namespace KParts
 {
-class BrowserExtension;
+//TODO KF6: when removing compatibility with KF5, uncomment the line below
+//class NavigationExtension;
 class StatusBarExtension;
 }
 
+#if QT_VERSION_MAJOR < 6
 #ifdef KActivities_FOUND
 namespace KActivities
 {
 class ResourceInstance;
 }
 #endif
+#endif
+
+namespace Konq {
+    class PlaceholderPart;
+}
 
 // TODO: make the history-handling code reuseable (e.g. in kparts) for people who want to use a
 // khtml-based browser in some apps. Back/forward support is all in here currently.
 struct HistoryEntry {
     void loadItem(const KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options);
     void saveConfig(KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options);
+    static HistoryEntry* fromDelayedLoadingData(const KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options);
 
     QUrl url;
     QString locationBarURL; // can be different from url when showing a index.html
@@ -71,7 +81,14 @@ class KONQ_TESTS_EXPORT KonqView : public QObject
 public:
 
     /**
-     * Create a konqueror view
+     * @brief Constructor which creates a view with a PlaceholderPart
+     * @param viewFrame the frame which will contain the view
+     * @param mainWindow the main window the view will belong to
+     */
+    KonqView(KonqFrame *viewFrame, KonqMainWindow* mainWindow);
+
+    /**
+     * Create a konqueror view with an appropriate part
      * @param viewFactory the factory to be used to create the part
      * @param viewFrame the frame where to create the view
      * @param mainWindow is the main window :-)
@@ -299,7 +316,7 @@ public:
         return m_bAborted;
     }
 
-    KParts::BrowserExtension *browserExtension() const;
+    KParts::NavigationExtension *browserExtension() const;
 
     KParts::StatusBarExtension *statusBarExtension() const;
 
@@ -481,7 +498,7 @@ public:
 
     // Called before reloading this view. Sets args.reload to true, and offers to repost form data.
     // Returns false in case the reload must be canceled.
-    bool prepareReload(KParts::OpenUrlArguments &args, KParts::BrowserArguments &browserArgs, bool softReload);
+    bool prepareReload(KParts::OpenUrlArguments &args, BrowserArguments &browserArgs, bool softReload);
 
     // overload for the QString version
     void setLocationBarURL(const QUrl &locationBarURL);
@@ -504,6 +521,13 @@ public:
     void saveConfig(KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options);
     void loadHistoryConfig(const KConfigGroup &config, const QString &prefix);
 
+    /**
+     * @brief Creates a view and load an URL according to the delayed loading data and the history content
+     *
+     * It does nothing if there's no delayed loading data
+     */
+    void loadDelayed();
+
     /**
      * @brief Changes the part used to display the current url
      * @param newPluginId the plugin id of the new part to use
@@ -515,6 +539,34 @@ public:
      */
     void switchEmbeddingPart(const QString &newPluginId, const QString &newInternalViewMode = {});
 
+    /**
+     * @brief Stores the information needed to restore the state of the view
+     *
+     * The history-related information is directly read in #m_lstHistory and #m_lstHistoryIndex,
+     * while the part-specific information is stored in #m_delayedLoadingData.
+     *
+     * This function allows to load the content of the view only when it actually becomes visible
+     * @param mimeType the mimetype of the URL
+     * @param serviceName the id of the part to use
+     * @param openUrl whether an URL should be loaded when the part will be created
+     * @param url the URL to load when the part will be created
+     * @param lockedLocation whether to block the URL when the view will be created
+     * @param grp the object to read configuration options from
+     * @param prexfix the prefix to add to configuration options names when reading from @p grp
+     */
+    void storeDelayedLoadingData(const QString &mimeType, const QString &serviceName, bool openUrl, const QUrl &url,
+                                 bool lockedLocation, const KConfigGroup &grp, const QString &prefix);
+
+    /**
+     * @brief Whether or not loading this view has been delayed
+     *
+     * When this function returns `true` it means that loadDelayed() should be called next time
+     * the tab containing this view is activated.
+     *
+     * @return `true` if the loading has been delayed and `false` otherwise
+     */
+    bool isDelayed() const;
+
 Q_SIGNALS:
 
     /**
@@ -535,7 +587,7 @@ public Q_SLOTS:
      */
     void setLocationBarURL(const QString &locationBarURL);
     /**
-     * get an icon for the URL from the BrowserExtension
+     * get an icon for the URL from the NavigationExtension
      */
     void setIconURL(const QUrl &iconURL);
 
@@ -557,9 +609,20 @@ private Q_SLOTS:
     void slotCanceled(const QString &errMsg);
     void slotPercent(KJob *, unsigned long percent);
     void slotSpeed(KJob *, unsigned long bytesPerSecond);
+    void slotPopupMenuFiles(const QPoint &global,
+            const KFileItemList &items,
+            const KParts::OpenUrlArguments &args,
+            KParts::NavigationExtension::PopupFlags flags,
+            const KParts::NavigationExtension::ActionGroupMap &actionGroups);
+    void slotPopupMenuUrl(const QPoint &global,
+                   const QUrl &url,
+                   mode_t mode,
+                   const KParts::OpenUrlArguments &arguments,
+                   KParts::NavigationExtension::PopupFlags flags,
+                   const KParts::NavigationExtension::ActionGroupMap &actionGroups);
 
     /**
-     * Connected to the BrowserExtension
+     * Connected to the NavigationExtension
      */
     void slotSelectionInfo(const KFileItemList &items);
     void slotMouseOverInfo(const KFileItem &item);
@@ -572,9 +635,16 @@ private Q_SLOTS:
 
 private:
     /**
-     * Replace the current view with a new view, created by @p viewFactory.
+     * Replace the current part with a new part, created by @p viewFactory.
+     *
+     * If the factory isn't valid and @p allowPlaceholder is `true`, a PlaceholderPart
+     * will be created.
+     *
+     * @param viewFactory the factory to use to create the part
+     * @param allowPlaceholder whether a PlaceholderPart should be used if @p viewFactory isn't valid.
+     *  If this is `false` and @p viewFactory is invalid, nothing will be done
      */
-    void switchView(KonqViewFactory &viewFactory);
+    void switchView(KonqViewFactory &viewFactory, bool allowPlaceholder = false);
 
     /**
      * Connects the internal part to the main window.
@@ -607,6 +677,12 @@ private:
 
     bool eventFilter(QObject *obj, QEvent *e) override;
 
+    /**
+     * @brief Casts the part associated with the view to a Konq::PlaceholderPart
+     * @return the part associated with the view cast to a Konq::PlaceholderPart or `nullptr` if it's not a Konq::PlaceholderPart
+     */
+    Konq::PlaceholderPart *placeholderPart() const;
+
 ////////////////// private members ///////////////
 
     KParts::ReadOnlyPart *m_pPart;
@@ -640,7 +716,7 @@ private:
     QString m_pageReferrer;
 
     KonqMainWindow *m_pMainWindow;
-    UrlLoader *m_loader;
+    UrlLoader *m_loader = nullptr;
     KonqFrame *m_pKonqFrame;
 
     uint m_bLoading: 1;
@@ -666,9 +742,11 @@ private:
     QString m_tempFile;
     QString m_dbusObjectPath;
 
+#if QT_VERSION_MAJOR < 6
 #ifdef KActivities_FOUND
     KActivities::ResourceInstance *m_activityResourceInstance;
 #endif
+#endif
 };
 
 #endif
